@@ -1,9 +1,6 @@
 # -*- coding: utf-8 -*-
 
 import re
-from collections import Counter
-
-import pointofview
 
 from prosegrinder.dictionary import Dictionary
 from prosegrinder.fragment import Fragment
